@@ -32,8 +32,8 @@ class AutoMapperValueParser:
             from spark_auto_mapper.data_types.complex.struct import AutoMapperDataTypeStruct
             return AutoMapperDataTypeStruct(value=value)
         if isinstance(value, List):
-            from spark_auto_mapper.data_types.list import AutoMapperDataTypeList
-            return AutoMapperDataTypeList(value=value)
+            from spark_auto_mapper.data_types.list import AutoMapperList
+            return AutoMapperList(value=value)
 
         if isinstance(value, AutoMapperDataTypeBase):
             return value
